# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/cart/invoice/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/cart/invoice/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Cart\\Invoice\\": "packages/cart/invoice/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Cart\Invoice\Providers\InvoiceServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Invoice'  => Cart\Invoice\Facades\Invoice::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Cart\\InvoiceTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Cart\Invoice\Providers\InvoiceServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Cart\Invoice\Providers\InvoiceServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Cart\Invoice\Providers\InvoiceServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/invoice/{modulename}

**User**

    http://path-to-route-folder/user/invoice/{modulename}

**Public**

    http://path-to-route-folder/invoices


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/invoice/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/invoice/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/invoice/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/invoice/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/invoice/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/invoice/{modulename}/{slug}
    METHOD: GET